from fastapi.responses import ORJSONResponse
from sredis.sredis import get_datacenter_token, rr_get
from fastapi import HTTPException
import requests
import json


def proxy_datacenters(
    serverpath: str,
    username,
    method="GET",
    body="",
    balancer_fun=rr_get,
    datacenter=None,
):
    if "datacenter" in body:
        server = body["datacenter"]
    elif datacenter:
        server = datacenter
    else:
        server = balancer_fun()
    token = get_datacenter_token(username, server)
    url = f"{server}/{serverpath}"
    t_resp = requests.request(
        json=body,
        method=method,
        url=url,
        allow_redirects=True,
        verify=False,
        headers={"Authorization": token},
    )
    if int(t_resp.status_code / 100) != 2:
        raise HTTPException(
            status_code=t_resp.status_code, detail="Remote server error"
        )
    obj = json.loads(t_resp.content)
    if type(obj) is list:
        for o in obj:
            o["datacenter"] = server
    else:
        obj["datacenter"] = server
    response = ORJSONResponse(obj, status_code=t_resp.status_code)
    return response
